
.. _device-reference:

Device Documentation
====================

Introduction
------------

This section contains the Doxygen documentation for the xscope_io_device file API.
This documentation provides a detailed understanding of each function, including parameters and usage guidelines.

To use xscope_fileio in your application, include the following header file:

.. code-block:: c

    #include "xscope_fileio_device.h"
    
Device API
----------

.. doxygengroup:: xscope_fileio_device
    :project: xscope_fileio
    :members:
